module HostsAndHostgroupsHelper
  include AncestryHelper

  def model_name(host)
    name = host.try(:model)
    name = host.compute_resource.name if host.compute_resource
    name
  end

  def domain_subnets(type)
    accessible_related_resource(@domain, :subnets, :where => {:type => type})
  end

  def arch_oss
    accessible_related_resource(@architecture, :operatingsystems)
  end

  def os_media
    accessible_related_resource(@operatingsystem, :media)
  end

  def os_ptable
    accessible_related_resource(@operatingsystem, :ptables)
  end

  INHERIT_TEXT = N_("inherit")

  def realm_field(f, can_override = false, override = false)
    # Don't show this if we have no Realms, otherwise always include blank
    # so the user can choose not to use a Realm on this host
    return unless (SETTINGS[:unattended] == true) && @host.managed
    realms = accessible_resource(f.object, :realm)
    return unless realms.present?
    select_f(f, :realm_id,
                realms,
                :id, :to_label,
                { :include_blank => true,
                  :disable_button => can_override ? _(INHERIT_TEXT) : nil,
                  :disable_button_enabled => override && !explicit_value?(:realm_id),
                  :user_set => user_set?(:realm_id)
                },
                { :help_inline   => :indicator }
            ).html_safe
  end

  def multiple_filter(hosts)
    return unless multiple_with_filter?
    no_filter   = _("Reminder: <strong> All #{hosts.size} hosts are selected </strong>").html_safe
    with_filter = _("Reminder: <strong> All #{hosts.size} hosts are selected </strong> for query filter #{h(params[:search])}").html_safe
    params[:search].blank? ? no_filter : with_filter
  end
end
